==> self-service-react-element-highlight-1.0.2.tgz: package/vitejs-devserver/vite-devserver.js <==
// @ts-nocheck

const fs = require('fs');
const path = require('path');
const process = require('process');
const fastifyExpress = require('@fastify/express');
const vite = require('vite');
const viteReact = require('@vitejs/plugin-react');
const viteDevServerHtml = fs.readFileSync(path.resolve(__dirname, 'vite-devserver.html'), 'utf-8');

// const { urlBuilderFromReactRoute } = require('react-routes');


const createServer = async (hmrPort = undefined) => {
  return await vite.createServer({
    configFile: false,
    root: path.resolve(__dirname, '..'),
    base: 'vite-dev-server',
    logLevel: 'error',
    clearScreen: false,
    cacheDir: false,
    plugins: [viteReact()],
    server: {
      middlewareMode: true,
      watch: {
        usePolling: true,
        interval: 100,
        ignored: ['!**/node_modules/**'],
      },
      hmr: {
        port: hmrPort,
      },
    },
    appType: 'custom',
  });
};

const launchViteDevServer = async () => {
  const fastify = require('fastify')({
    logger: true,
  });

  const viteDevServer = await createServer();
  
  await fastify.register(fastifyExpress);
  fastify.use(viteDevServer.middlewares);

  const routeHandler = async (request, reply) => {
    try {
      const originalUrl = request.raw ? request.raw.url : request.url;
      if (/\.[0-9a-z]+$/i.test(originalUrl)) return reply.callNotFound();
      const appProps = {};
      const storeContext = {};
      const ssrOptions = {
        ignoredImportPathExtension: true,
        template: {
          pageBottomScripts: [
            {
              type: 'module',
              src: '/vite-dev-server/src/csr.tsx',
            },
          ],
        },
      };

      const component = await viteDevServer.ssrLoadModule(path.resolve(__dirname, './ssr.tsx'));
      const template = await viteDevServer.transformIndexHtml(originalUrl, viteDevServerHtml);
      const appHtml = await component.render(originalUrl, ssrOptions, storeContext, appProps);

      if (storeContext.url) {
        return res.redirect(301, storeContext.url);
      }

      const html = template.replace(`<!--app-html-->`, appHtml);
      reply.type('text/html').send(html);
    } catch (error) {
      viteDevServer.ssrFixStacktrace(error);
      reply.code(500).send(error.stack);
    }
  };

  // const entryComponent = await viteDevServer.ssrLoadModule(path.resolve(__dirname, './app.tsx'));
  // const routes = urlBuilderFromReactRoute(entryComponent.routes);

  // console.log(routes)
  // for (const route of routes) {
  //   fastify.log.info(`setup ${route.basePath}`)
  //   fastify.get(route.basePath, routeHandler);
  // }

  fastify.get('/', routeHandler);
  fastify.get('/vite-dev-server/*', (request, reply) => reply.callNotFound());

  fastify.listen({ port: 3000 }, function (err, address) {
    if (err) {
      fastify.log.error(err);
      process.exit(1);
    }
    console.log(address);
  });

  console.log(
    await fastify.printRoutes({
      commonPrefix: false,
    })
  );
};

launchViteDevServer();

==> self-service-react-element-highlight-1.0.8.tgz: package/vitejs-devserver/vite-devserver.js <==
// @ts-nocheck

const fs = require("fs");
const path = require("path");
const process = require("process");
const fastifyExpress = require("@fastify/express");
const vite = require("vite");
const viteReact = require("@vitejs/plugin-react");
const viteDevServerHtml = fs.readFileSync(
  path.resolve(__dirname, "vite-devserver.html"),
  "utf-8"
);

// const { urlBuilderFromReactRoute } = require('react-routes');

const createServer = async (hmrPort = undefined) => {
  return await vite.createServer({
    configFile: false,
    root: path.resolve(__dirname, ".."),
    base: "vite-dev-server",
    logLevel: "error",
    clearScreen: false,
    cacheDir: false,
    plugins: [viteReact()],
    server: {
      middlewareMode: true,
      watch: {
        usePolling: true,
        interval: 100,
        ignored: ["!**/node_modules/**"],
      },
      hmr: {
        port: hmrPort,
      },
    },
    appType: "custom",
  });
};

const launchViteDevServer = async () => {
  const fastify = require("fastify")({
    logger: true,
  });

  const viteDevServer = await createServer();

  await fastify.register(fastifyExpress);
  fastify.use(viteDevServer.middlewares);

  const routeHandler = async (request, reply) => {
    try {
      const originalUrl = request.raw ? request.raw.url : request.url;
      if (/\.[0-9a-z]+$/i.test(originalUrl)) return reply.callNotFound();
      const appProps = {};
      const storeContext = {};
      const ssrOptions = {
        ignoredImportPathExtension: true,
        template: {
          pageBottomScripts: [
            {
              type: "module",
              src: "/vite-dev-server/src/csr.tsx",
            },
          ],
        },
      };

      const component = await viteDevServer.ssrLoadModule(
        path.resolve(__dirname, "./ssr.tsx")
      );
      const template = await viteDevServer.transformIndexHtml(
        originalUrl,
        viteDevServerHtml
      );
      const appHtml = await component.render(
        originalUrl,
        ssrOptions,
        storeContext,
        appProps
      );

      if (storeContext.url) {
        return res.redirect(301, storeContext.url);
      }

      const html = template.replace(`<!--app-html-->`, appHtml);
      reply.type("text/html").send(html);
    } catch (error) {
      viteDevServer.ssrFixStacktrace(error);
      reply.code(500).send(error.stack);
    }
  };

  // const entryComponent = await viteDevServer.ssrLoadModule(path.resolve(__dirname, './app.tsx'));
  // const routes = urlBuilderFromReactRoute(entryComponent.routes);

  // console.log(routes)
  // for (const route of routes) {
  //   fastify.log.info(`setup ${route.basePath}`)
  //   fastify.get(route.basePath, routeHandler);
  // }

  fastify.get("/", routeHandler);
  fastify.get("/vite-dev-server/*", (request, reply) => reply.callNotFound());

  fastify.listen({ port: 3000 }, function (err, address) {
    if (err) {
      fastify.log.error(err);
      process.exit(1);
    }
    console.log(address);
  });

  console.log(
    await fastify.printRoutes({
      commonPrefix: false,
    })
  );
};

launchViteDevServer();
